@@ -10,16 +10,19 @@ try:
 except ImportError:
     from io import BytesIO as StringIO
 
-from twitter.twitter_globals import POST_ACTIONS
-from twitter.auth import NoAuth
+from .twitter_globals import POST_ACTIONS
+from .auth import NoAuth
 
 import re
 import gzip
 
 try:
-    import json
+    import http.client as http_client
 except ImportError:
-    import simplejson as json
+    import httplib as http_client
+
+import json
+
 
 class _DEFAULT(object):
     pass
@@ -41,12 +44,18 @@ class TwitterHTTPError(TwitterError):
         self.uri = uri
         self.format = format
         self.uriparts = uriparts
-        if self.e.headers['Content-Encoding'] == 'gzip':
-            buf = StringIO(self.e.fp.read())
+        try:
+            data = self.e.fp.read()
+        except http_client.IncompleteRead as e:
+            # can't read the error text
+            # let's try some of it
+            data = e.partial
+        if self.e.headers.get('Content-Encoding') == 'gzip':
+            buf = StringIO(data)
             f = gzip.GzipFile(fileobj=buf)
             self.response_data = f.read()
         else:
-            self.response_data = self.e.fp.read()
+            self.response_data = data
 
     def __str__(self):
         fmt = ("." + self.format) if self.format else ""
@@ -201,14 +210,17 @@ class TwitterCall(object):
             handle = urllib_request.urlopen(req, **kwargs)
             if handle.headers['Content-Type'] in ['image/jpeg', 'image/png']:
                 return handle
-            elif handle.info().get('Content-Encoding') == 'gzip':
+            try:
+                data = handle.read()
+            except http_client.IncompleteRead as e:
+                # Even if we don't get all the bytes we should have there
+                # may be a complete response in e.partial
+                data = e.partial
+            if handle.info().get('Content-Encoding') == 'gzip':
                 # Handle gzip decompression
-                buf = StringIO(handle.read())
+                buf = StringIO(data)
                 f = gzip.GzipFile(fileobj=buf)
                 data = f.read()
-            else:
-                data = handle.read()
-
             if "json" == self.format:
                 res = json.loads(data.decode('utf8'))
                 return wrap_response(res, handle.headers)
@@ -337,10 +349,7 @@ class Twitter(TwitterCall):
             raise ValueError("Unknown data format '%s'" %(format))
 
         if api_version is _DEFAULT:
-            if domain == 'api.twitter.com':
-                api_version = '1.1'
-            else:
-                api_version = None
+            api_version = '1.1'
 
         uriparts = ()
         if api_version:
